@@ -294,8 +294,7 @@ sub DynamicFieldGet {
     }
 
     # get yaml object
-    my $YAMLObject      = $Kernel::OM->Get('Kernel::System::YAML');
-    my $HTMLUtilsObject = $Kernel::OM->Get('Kernel::System::HTMLUtils');
+    my $YAMLObject = $Kernel::OM->Get('Kernel::System::YAML');
 
     my %Data;
     while ( my @Data = $DBObject->FetchrowArray() ) {
@@ -1725,13 +1724,7 @@ sub _SanitizeConfig {
         return;
     }
 
-    if ( !IsHashRefWithData( $Param{Config} ) ) {
-        $LogObject->Log(
-            Priority => 'error',
-            Message  => "Parameter 'Config' must be a hash ref with data!",
-        );
-        return;
-    }
+    return if !IsHashRefWithData( $Param{Config} );
 
     # Remove JavaScript, etc. from regex error messages.
     # This prevents execution of arbitrary JavaScript when showing
